@@ -11,6 +11,9 @@ from torch.utils.data import Dataset
 import torchvision.datasets as datasets
 
 from .evaluator.general_evaluator import GeneralEvaluator
+from zcls.util import logging
+
+logger = logging.get_logger(__name__)
 
 
 class GeneralDataset(Dataset):
@@ -21,6 +24,9 @@ class GeneralDataset(Dataset):
         self.root = root
         self._update_evaluator(top_k)
 
+        # logger.info(self.classes)
+        # logger.info(self.root)
+
     def __getitem__(self, index: int):
         return self.data_set.__getitem__(index)
 
